sqfentity_gen_2

This package required for sqfentity_2 ORM for Flutter code generator, a 16KB page-size compliant fork of sqfentity_gen built against the current Flutter/AGP/NDK toolchain for Android 16KB native library alignment. Includes Generators and Converters with build.yaml

Getting Started

click for more information: https://github.com/hhtokpinar/sqfEntity

Libraries

builder
Configuration for using package:build-compatible build systems.
sqfentity_gen
**************************** LICENSE ***************************** Copyright (C) 2019, HUSEYIN TOKPUNAR http://huseyintokpinar.com/ Download & Update Latest Version: https://github.com/hhtokpinar/sqfEntity Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. **********************************************************************/