SqfEntityField constructor
const
SqfEntityField(})
This class is required for field definitions using in a table definition Simple field definition must be below:
SqfEntityField('name', DbType.text, isNotNull: true),
Implementation
const SqfEntityField(this.fieldName, this.dbType,
{this.defaultValue,
this.minValue,
this.maxValue,
this.sequencedBy,
this.isPrimaryKeyField,
this.isNotNull,
this.isUnique,
this.isIndex,
this.isIndexGroup,
this.checkCondition,
this.formLabelText,
this.collate});